==> TopdataTopFinderProSW6-v8.1.6.zip: TopdataTopFinderProSW6/manual/30-settings.de.md <==
---
title: Konfiguration & Einstellungen
---

Alle Einstellungen für das Topdata TopFinder Pro Plugin finden Sie in Ihrem Shopware Admin unter `Erweiterungen > Meine Erweiterungen > ... > Konfigurieren`. Die Konfiguration ist zur Übersichtlichkeit in mehrere Abschnitte unterteilt.

### Auswahl Felder

Dieser Abschnitt steuert die Haupt-Finder-Leiste, die in Ihrem Storefront angezeigt wird.

- **Angezeigte Dropdown-Menüs auswählen**: Definiert die Struktur des Finders.
  - **Optionen**:
    - `Hersteller - Serie - Geräte`: Ein dreistufiger Auswahlprozess.
    - `Hersteller - Typen - Geräte`: Ein alternativer dreistufiger Prozess.
    - `Hersteller - Typen/Serie - Geräte`: (Standard) Ein dreistufiger Prozess mit einem Schalter zum Wechseln zwischen Serie und Typ.
    - `Hersteller - Geräte`: Ein vereinfachter zweistufiger Prozess.
- **Auswahlfelder anzeigen**: Bestimmt, wo die Finder-Leiste erscheint.
  - **Optionen**: `auf alle Seiten` (Standard), `nur auf Topfinder Seiten`, `nicht anzeigen`.
- **Nach Auswahl die Seite "Marke / Serie / Typ" anzeigen**: Wenn aktiviert, navigiert die Auswahl einer Option (z.B. einer Marke) den Benutzer zur Seite dieser Marke, anstatt nur das nächste Dropdown zu laden. Standard: `Deaktiviert`.
- **Verlauf der gesuchten Geräte anzeigen**: Wenn aktiviert, wird ein Dropdown mit kürzlich angesehenen Geräten in der Finder-Leiste angezeigt. Standard: `Aktiviert`.
- **Benutzer darf Dropdown-Menüs ausblenden**: Wenn aktiviert, können Benutzer die Finder-Leiste einklappen. Standard: `Aktiviert`.
- **Dropdowns Spalten Klasse**: Geben Sie die Bootstrap-Spaltenklassen ein, um das Layout der Dropdowns zu steuern (z.B. `col-sm-4 col-md` für ein horizontales Layout, `col-sm-12` für ein vertikales). Standard: `col-sm-4 col-md`.
- **Lade-Spinner Anzeigemodus**: Wie die Ladeanzeige bei AJAX-Anfragen dargestellt wird.
  - **Optionen**: `Keine`, `Overlay` (Standard).
- **Position der Finder-Leiste**: Steuert, wo die Finder-Leiste auf der Seite gerendert wird.
  - **Optionen**: `Seitenanfang (über dem Header)` (Standard), `Über der Hauptnavigation (unter der Suchleiste)`, `Unter der Hauptnavigation`.

### ABC Leiste

Dies steuert die A-Z-Navigationsleiste.

- **ABC Leiste anzeigen**: Schaltet die Sichtbarkeit der A-Z-Navigationsleiste um. Standard: `Aktiviert`.
- **Zeige Geräte satt Marken bei der Suche über die ABC-Leiste**: Wenn aktiviert, führt ein Klick auf einen Buchstaben zu einer Liste von Geräten. Wenn deaktiviert, wird eine Liste von Marken angezeigt. Standard: `Deaktiviert`.
- **Leere Buchstaben deaktivieren**: Wenn aktiviert, werden Buchstaben in der A-Z-Leiste, die keine zugehörigen Marken/Geräte haben, ausgegraut und sind nicht klickbar. Standard: `Aktiviert`.

### Druckerverlauf und Slider

Dies steuert die Funktionalität des Geräteverlaufs.

- **Anzahl der zuletzt gesuchten Geräte festlegen**: Wie viele kürzlich angesehene Geräte gespeichert werden. Standard: `10`.
- **Den Verlauf der zuletzt gesuchten Geräte auf allen Seiten anzeigen**: Wenn aktiviert, erscheint ein Slider mit kürzlich angesehenen Geräten im Storefront. Standard: `Aktiviert`.
- **Slider mit den zuletzt gesuchten Druckern (Historie) ausgeblenden**: Wenn aktiviert, können Benutzer den Slider des Geräteverlaufs ausblenden. Standard: `Aktiviert`.

### Geräte-Finder-Popup

Dies steuert den modal-basierten Finder.

- **Zusätzliches Popup mit Druckerfinder anzeigen**: Schaltet den Button im Header um, der das Popup öffnet. Standard: `Aktiviert`.
- **Angezeigte Dropdown-Menüs im Druckerfinder auswählen...**: Legt die Dropdown-Struktur innerhalb des Popups fest (dieselben Optionen wie die Haupt-Finder-Leiste). Standard: `Hersteller - Typen/Serie - Geräte`.
- **Verlauf der gesuchten Geräte anzeigen**: Schaltet die Verlaufsfunktion innerhalb des Popups um. Standard: `Aktiviert`.
- **Farbeinstellungen**: Eine Reihe von Farbwählern (`Background dark`, `Background light`, etc.), um das visuelle Erscheinungsbild des Popup-Finders an Ihr Theme anzupassen.

### Produktdetailseite

Dies steuert Funktionen auf der Produktdetailseite.

- **Kompatible Geräte anzeigen lassen**: Schaltet den Tab "Kompatible Geräte" um. Standard: `Aktiviert`.
- **Gruppierung der kompatiblen Geräte...**: Wie Geräte innerhalb des Tabs gruppiert werden.
  - **Optionen**: `Gruppe nach Serie` (Standard), `Gruppe nach Hersteller`, `Keine Gruppierung`.
- **Legen Sie fest, wie die Gerätenamen dargestellt werden sollen**: Wie Gerätenamen in Listen formatiert werden.
  - **Optionen**: `Drucker`, `Marke + Drucker` (Standard), `Marke + Neue Zeile + Drucker`.
- **Anzeigen der Unternavigation** (`fixProductBreadcrumbs`): Passt den Breadcrumb-Pfad auf Produktseiten für einen besseren Kontext an. Standard: `Aktiviert`.

### Suche

Dies steuert die Gerätesuch-Integration.

- **Suche Eingabefeld**:
  - **Optionen**:
    - `Kombiniert mit Produktsuche` (Standard): Ergebnisse der Gerätesuche werden neben den regulären Produktsuch-Ergebnissen angezeigt.
    - `eignenes Suchfeld`: Eine separate Suchleiste für Geräte wird angezeigt.
    - `deaktiviert`: Die Gerätesuche ist deaktiviert.
- **Wenn keine Gerät gefunden, Resultat nicht anzeigen**: Verbirgt den Abschnitt mit den Geräteergebnissen in der kombinierten Suche, wenn keine Geräte gefunden werden. Standard: `Aktiviert`.

### Device List

Dies steuert die Funktion für eingeloggte Kunden.

- **Persönliche Geräteliste aktivieren**: Aktiviert die Funktion "Meine Geräteliste", die es eingeloggten Kunden ermöglicht, ihre Geräte zu speichern. Standard: `Aktiviert`.

### Geräteansicht im Kompaktmodus

Diese Einstellungen definieren den Schwellenwert, ab dem eine detaillierte Ansicht zu einer kompakteren Listenansicht wechselt, um Platz zu sparen.

- **Anzahl der Suchergebnisse**: Standard `10`.
- **Anzahl der Geräte auf Ihrer persönlichen Geräteliste**: Standard `10`.
- **Anzahl der kompatiblen Drucker auf der Produktdetailseite**: Standard `3`.

### Seite mit Gerätedetails

Dies steuert die Produktlistings auf den automatisch generierten Geräteseiten.

- **Eigenschaft zum Gruppieren von Produkten nach Registerkarten**: Ermöglicht die Auswahl einer Produkteigenschaftsgruppe (z.B. "Zustand"). Produkte auf der Geräteseite werden basierend auf den Werten dieser Eigenschaft in Tabs aufgeteilt (z.B. ein Tab für "Original" und ein Tab für "Kompatibel").
- **Standard-Produktsortierung**: Legt die standardmäßige Sortierreihenfolge für Produkte auf Geräteseiten fest. Standard: `Topseller`.
- **Produkte pro Seite**: Legt die Anzahl der pro Seite anzuzeigenden Produkte fest. Standard: `10`.
- **Css-Klasse für Produktbox in Produktliste**: Geben Sie die Bootstrap-Spaltenklassen ein, um das Layout des Produktgitters auf den Geräteseiten zu steuern. Standard: `col-sm-6 col-lg-4 col-xl-3`.

### Warenkorb Einstellungen

- **Zuletzt verwendetes kompatibles Gerät im Warenkorb anzeigen**: Wenn aktiviert, wird dem Kunden beim Hinzufügen eines Produkts zum Warenkorb angezeigt, mit welchem seiner kürzlich angesehenen Geräte dieses Produkt kompatibel ist. Dies bietet dem Kunden eine zusätzliche Bestätigung. Standard: `Deaktiviert`.

==> TopdataTopFinderProSW6-v8.2.0.zip: TopdataTopFinderProSW6/manual/30-settings.de.md <==
---
title: Konfiguration & Einstellungen
---

Alle Einstellungen für das Topdata TopFinder Pro Plugin finden Sie in Ihrem Shopware Admin unter `Erweiterungen > Meine Erweiterungen > ... > Konfigurieren`. Die Konfiguration ist zur Übersichtlichkeit in mehrere Abschnitte unterteilt.

### Auswahl Felder

Dieser Abschnitt steuert die Haupt-Finder-Leiste, die in Ihrem Storefront angezeigt wird.

- **Angezeigte Dropdown-Menüs auswählen**: Definiert die Struktur des Finders.
  - **Optionen**:
    - `Hersteller - Serie - Geräte`: Ein dreistufiger Auswahlprozess.
    - `Hersteller - Typen - Geräte`: Ein alternativer dreistufiger Prozess.
    - `Hersteller - Typen/Serie - Geräte`: (Standard) Ein dreistufiger Prozess mit einem Schalter zum Wechseln zwischen Serie und Typ.
    - `Hersteller - Geräte`: Ein vereinfachter zweistufiger Prozess.
- **Auswahlfelder anzeigen**: Bestimmt, wo die Finder-Leiste erscheint.
  - **Optionen**: `auf alle Seiten` (Standard), `nur auf Topfinder Seiten`, `nicht anzeigen`.
- **Nach Auswahl die Seite "Marke / Serie / Typ" anzeigen**: Wenn aktiviert, navigiert die Auswahl einer Option (z.B. einer Marke) den Benutzer zur Seite dieser Marke, anstatt nur das nächste Dropdown zu laden. Standard: `Deaktiviert`.
- **Verlauf der gesuchten Geräte anzeigen**: Wenn aktiviert, wird ein Dropdown mit kürzlich angesehenen Geräten in der Finder-Leiste angezeigt. Standard: `Aktiviert`.
- **Benutzer darf Dropdown-Menüs ausblenden**: Wenn aktiviert, können Benutzer die Finder-Leiste einklappen. Standard: `Aktiviert`.
- **Dropdowns Spalten Klasse**: Geben Sie die Bootstrap-Spaltenklassen ein, um das Layout der Dropdowns zu steuern (z.B. `col-sm-4 col-md` für ein horizontales Layout, `col-sm-12` für ein vertikales). Standard: `col-sm-4 col-md`.
- **Lade-Spinner Anzeigemodus**: Wie die Ladeanzeige bei AJAX-Anfragen dargestellt wird.
  - **Optionen**: `Keine`, `Overlay` (Standard).
- **Position der Finder-Leiste**: Steuert, wo die Finder-Leiste auf der Seite gerendert wird.
  - **Optionen**: `Seitenanfang (über dem Header)` (Standard), `Über der Hauptnavigation (unter der Suchleiste)`, `Unter der Hauptnavigation`.

### ABC Leiste

Dies steuert die A-Z-Navigationsleiste.

- **ABC Leiste anzeigen**: Schaltet die Sichtbarkeit der A-Z-Navigationsleiste um. Standard: `Aktiviert`.
- **Zeige Geräte satt Marken bei der Suche über die ABC-Leiste**: Wenn aktiviert, führt ein Klick auf einen Buchstaben zu einer Liste von Geräten. Wenn deaktiviert, wird eine Liste von Marken angezeigt. Standard: `Deaktiviert`.
- **Leere Buchstaben deaktivieren**: Wenn aktiviert, werden Buchstaben in der A-Z-Leiste, die keine zugehörigen Marken/Geräte haben, ausgegraut und sind nicht klickbar. Standard: `Aktiviert`.

### Druckerverlauf und Slider

Dies steuert die Funktionalität des Geräteverlaufs.

- **Anzahl der zuletzt gesuchten Geräte festlegen**: Wie viele kürzlich angesehene Geräte gespeichert werden. Standard: `10`.
- **Den Verlauf der zuletzt gesuchten Geräte auf allen Seiten anzeigen**: Wenn aktiviert, erscheint ein Slider mit kürzlich angesehenen Geräten im Storefront. Standard: `Aktiviert`.
- **Slider mit den zuletzt gesuchten Druckern (Historie) ausgeblenden**: Wenn aktiviert, können Benutzer den Slider des Geräteverlaufs ausblenden. Standard: `Aktiviert`.

### Geräte-Finder-Popup

Dies steuert den modal-basierten Finder.

- **Zusätzliches Popup mit Druckerfinder anzeigen**: Schaltet den Button im Header um, der das Popup öffnet. Standard: `Aktiviert`.
- **Angezeigte Dropdown-Menüs im Druckerfinder auswählen...**: Legt die Dropdown-Struktur innerhalb des Popups fest (dieselben Optionen wie die Haupt-Finder-Leiste). Standard: `Hersteller - Typen/Serie - Geräte`.
- **Verlauf der gesuchten Geräte anzeigen**: Schaltet die Verlaufsfunktion innerhalb des Popups um. Standard: `Aktiviert`.
- **Farbeinstellungen**: Eine Reihe von Farbwählern (`Background dark`, `Background light`, etc.), um das visuelle Erscheinungsbild des Popup-Finders an Ihr Theme anzupassen.

### Produktdetailseite

Dies steuert Funktionen auf der Produktdetailseite.

- **Kompatible Geräte anzeigen lassen**: Schaltet den Tab "Kompatible Geräte" um. Standard: `Aktiviert`.
- **Gruppierung der kompatiblen Geräte...**: Wie Geräte innerhalb des Tabs gruppiert werden.
  - **Optionen**: `Gruppe nach Serie` (Standard), `Gruppe nach Hersteller`, `Keine Gruppierung`.
- **Legen Sie fest, wie die Gerätenamen dargestellt werden sollen**: Wie Gerätenamen in Listen formatiert werden.
  - **Optionen**: `Drucker`, `Marke + Drucker` (Standard), `Marke + Neue Zeile + Drucker`.
- **Anzeigen der Unternavigation** (`fixProductBreadcrumbs`): Passt den Breadcrumb-Pfad auf Produktseiten für einen besseren Kontext an. Standard: `Aktiviert`.

### Suche

Dies steuert die Gerätesuch-Integration.

- **Suche Eingabefeld**:
  - **Optionen**:
    - `Kombiniert mit Produktsuche` (Standard): Ergebnisse der Gerätesuche werden neben den regulären Produktsuch-Ergebnissen angezeigt.
    - `eignenes Suchfeld`: Eine separate Suchleiste für Geräte wird angezeigt.
    - `deaktiviert`: Die Gerätesuche ist deaktiviert.
- **Wenn keine Gerät gefunden, Resultat nicht anzeigen**: Verbirgt den Abschnitt mit den Geräteergebnissen in der kombinierten Suche, wenn keine Geräte gefunden werden. Standard: `Aktiviert`.

### Device List

Dies steuert die Funktion für eingeloggte Kunden.

- **Persönliche Geräteliste aktivieren**: Aktiviert die Funktion "Meine Geräteliste", die es eingeloggten Kunden ermöglicht, ihre Geräte zu speichern. Standard: `Aktiviert`.

### Geräteansicht im Kompaktmodus

Diese Einstellungen definieren den Schwellenwert, ab dem eine detaillierte Ansicht zu einer kompakteren Listenansicht wechselt, um Platz zu sparen.

- **Anzahl der Suchergebnisse**: Standard `10`.
- **Anzahl der Geräte auf Ihrer persönlichen Geräteliste**: Standard `10`.
- **Anzahl der kompatiblen Drucker auf der Produktdetailseite**: Standard `3`.

### Seite mit Gerätedetails

Dies steuert die Produktlistings auf den automatisch generierten Geräteseiten.

- **Eigenschaft zum Gruppieren von Produkten nach Registerkarten**: Ermöglicht die Auswahl einer Produkteigenschaftsgruppe (z.B. "Zustand"). Produkte auf der Geräteseite werden basierend auf den Werten dieser Eigenschaft in Tabs aufgeteilt (z.B. ein Tab für "Original" und ein Tab für "Kompatibel").
- **Standard-Produktsortierung**: Legt die standardmäßige Sortierreihenfolge für Produkte auf Geräteseiten fest. Standard: `Topseller`.
- **Produkte pro Seite**: Legt die Anzahl der pro Seite anzuzeigenden Produkte fest. Standard: `10`.
- **Css-Klasse für Produktbox in Produktliste**: Geben Sie die Bootstrap-Spaltenklassen ein, um das Layout des Produktgitters auf den Geräteseiten zu steuern. Standard: `col-sm-6 col-lg-4 col-xl-3`.

### Geräteverfügbarkeit

Diese Einstellung steuert, wie das System mit Geräten aus dem Topdata-Katalog umgeht, die nach einem Import nicht mit Produkten in Ihrem Shop verknüpft sind. Dies ist besonders nützlich, um zu kontrollieren, welche Geräte im TopFinder erscheinen.

- **Strategie für Geräteverfügbarkeit**:
  - **Optionen**:
    - `Geräte ohne Produkte deaktivieren (Standard)`: Dies ist das Standardverhalten. Nach einem Import der Produkt-Geräte-Verknüpfungen wird jedes Gerät, jede Marke, jede Serie und jeder Typ, der nicht mit mindestens einem Produkt verknüpft ist, deaktiviert und erscheint nicht im Finder des Shops.
    - `Alle Geräte aktiviert lassen`: Wählen Sie diese Option, wenn alle Geräte aus dem Topdata-Katalog im Finder aktiv und sichtbar bleiben sollen, unabhängig davon, ob sie mit Produkten in Ihrem Shop verknüpft sind. Dies kann nützlich sein, wenn Sie Ihren Kunden die volle Bandbreite der unterstützten Geräte zeigen möchten, auch wenn die entsprechenden Produkte noch nicht verfügbar sind.
    
### Warenkorb Einstellungen

- **Zuletzt verwendetes kompatibles Gerät im Warenkorb anzeigen**: Wenn aktiviert, wird dem Kunden beim Hinzufügen eines Produkts zum Warenkorb angezeigt, mit welchem seiner kürzlich angesehenen Geräte dieses Produkt kompatibel ist. Dies bietet dem Kunden eine zusätzliche Bestätigung. Standard: `Deaktiviert`.
